@@ -1,5 +1,5 @@
 #battle.py
-#Copyright (C) 2004 Free Software Foundation
+#Copyright (C) 2005 Free Software Foundation
 #see GPL.txt for license.
 
 #this file controls the window_battle window.
@@ -55,6 +55,12 @@ def refresh():
 
 	#hp/ep bars
 	canvas_mon_hp.delete("show_mon_hp")
+	canvas_mon_pic.itemconfig(canvas_mon_pic.find_withtag("mon_hp"),
+			text=str(monster_list[cur_monster].hp) + "/" +
+			str(monster_list[cur_monster].maxhp))
+
+#	create_text(170, 168, anchor=NW, text=mon_hp, tags="mon_hp")
+
 	temp_width = g.hpbar_width*int(monster_list[cur_monster].hp) / \
 										int(monster_list[cur_monster].maxhp)
 	if temp_width < 0: temp_width=0
@@ -132,13 +138,25 @@ def monster_dead():
 	#add info to listbox_move; add gold and xp
 	main.print_message("The " + monster_list[cur_monster].name +
 	" dies.")
-	gold = monster_list[cur_monster].gold
-	g.gold = str(int(g.gold) + gold)
-	main.print_message("You find " + str(gold) + " gold,")
 
-	exp = monster_list[cur_monster].exp
-	main.print_message("and get " + str(exp) + " experience.")
-	g.add_exp(exp)
+
+	if len(monster_list[cur_monster].on_death) == 0:
+		gold = monster_list[cur_monster].gold
+		g.gold = str(int(g.gold) + gold)
+		main.print_message("You find " + str(gold) + " gold,")
+
+		exp = monster_list[cur_monster].exp
+		main.print_message("and get " + str(exp) + " experience.")
+		g.add_exp(exp)
+	else:
+		i=0
+		while i < len(monster_list[cur_monster].on_death):
+			temp = action.activate_line(g.xgrid, g.ygrid, g.zgrid,
+				monster_list[cur_monster].on_death[i])
+			if temp == "end": break
+			if main.dead_yet() == 1:
+				break
+			i += 1
 
 	#finish up
 	window_battle.destroy()
@@ -540,7 +558,7 @@ def battle_show_yesno(line=""):
 
 	#background
 	canvas_battle2.create_rectangle(0, 0, canvas_width, canvas_height,
-		fill="#5050ff", outline="Black", tags="background_box")
+		fill=g.fill_colour, outline="Black", tags="background_box")
 	#text
 	canvas_battle2.create_text(3, 3, text=line, anchor="nw",
 		width=canvas_width-6, tags="dialogtxt")
@@ -655,8 +673,7 @@ def begin(mon_index_input):
 	pic_frame.grid(row=1, column=2, columnspan=3, rowspan=6, sticky=E)
 
 	global canvas_mon_pic
-	background_pic = ImageTk.PhotoImage(file=g.mod_directory +
-			"/images/monsters/generic.png")
+	background_pic = g.maps[g.zgrid].battle_background
 	if os.path.isfile(g.mod_directory +
 			"/images/tiles/monsters/" + monster_list[cur_monster].name + ".png"):
 		monster_pic = ImageTk.PhotoImage(file=g.mod_directory +
@@ -684,13 +701,13 @@ def begin(mon_index_input):
 	label_formatting = Label(window_battle,
 			text=monster_list[cur_monster].name, bg=bgcolour).grid(row=1,
 			column=1, columnspan=2)
-	label_formatting = Label(pic_frame,
-		text="HP:", bg="#327a22").grid(row=5, column=2, sticky=W, padx=2)
 
+	canvas_mon_pic.create_text(25, 168, anchor=NW, text="HP:")
+	canvas_mon_pic.create_text(152, 168, anchor=NW, text=mon_hp, tags="mon_hp")
 
 	#stat display
-	label_mon_hp = Label(pic_frame, textvariable=mon_hp,
-		bg="#327a22").grid(row=5, column=2, sticky=E, padx=2)
+#	label_mon_hp = Label(pic_frame, textvariable=mon_hp,
+#		bg="#327a22").grid(row=5, column=2, sticky=E, padx=2)
 
 	label_attack = Label(window_battle, text="Attack: " +
 	str(monster_list[cur_monster].attack), bg=bgcolour).grid(row=4,
@@ -755,7 +772,7 @@ def begin(mon_index_input):
 	run_button_loc = skill_button_loc + skill_button.width()
 
 	global canvas_buttons
-	canvas_buttons = Canvas(button_frame,
+	canvas_buttons = Canvas(button_frame, bg="#b3b3b3",
 		height=attack_button.height(),
 		width=attack_button.width() + run_button.width() +
 		item_button.width() + skill_button.width())
