@@ -1,11 +1,11 @@
 #g.py
-#Copyright (C) 2004 Free Software Foundation
+#Copyright (C) 2005 Free Software Foundation
 #see GPL.txt for license.
 
 #This file contains everything that needs to be accessed by most or all files.
 
 
-#Dragon Hunt 3.39. Released under the GPL. Copyright 2004
+#Dragon Hunt 3.40. Released under the GPL. Copyright 2005
 #(Note to self: when changing version, change variables.txt, README.txt,
 # and setup.py.)
 
@@ -21,8 +21,8 @@ from os import path, mkdir, remove, walk
 from scripting import *
 import monster
 import item
-import action
 import main
+import action
 
 #This will be displayed on the Title screen and Main screen.
 game_name = ""
@@ -47,6 +47,13 @@ adj_defense = 0
 adj_maxhp = 0
 adj_maxep = 0
 
+#fill colour
+fill_colour = "#b9e5ad"
+fill_sel_colour = "#7aa96e"
+outline_colour = "#70a662"
+#fill_colour = "#5050ff"
+#fill_sel_colour = "#A0A0ff"
+#outline_colour = "#202090"
 
 #default tile width. Set in variables.txt, or default to 32.
 tilesize = 32
@@ -530,3 +537,24 @@ def load_tiles():
 				else: #if image is in root dir
 					tiles[tilename] = \
 						ImageTk.PhotoImage(file=root + "/" + tilename)
+
+
+backgrounds = {}
+
+#This loads the battle backgrounds.
+def load_backgrounds():
+	global backgrounds
+	backgrounds = {"blank" : ImageTk.PhotoImage("RGB", (200, 200))}
+
+	for root, dirs, files in walk(g.mod_directory + "/images/backgrounds/"):
+		(head, tail) = path.split(root)
+		if (tail != "CVS"):
+			for tilename in files:
+				#if image is in a sub-dir:
+				if (root != g.mod_directory + "/images/backgrounds/"):
+					i = len(g.mod_directory + "/images/backgrounds/")
+					backgrounds[root[i:] + "/" + tilename] = \
+						ImageTk.PhotoImage(file=root + "/" + tilename)
+				else: #if image is in root dir
+					backgrounds[tilename] = \
+						ImageTk.PhotoImage(file=root + "/" + tilename)
