@@ -1,5 +1,5 @@
 #inv.py
-#Copyright (C) 2004 Free Software Foundation
+#Copyright (C) 2005 Free Software Foundation
 #see GPL.txt for license.
 
 #This file controls the inventory screen.
@@ -147,7 +147,7 @@ def inv_show_yesno(line=""):
 
 	#background
 	canvas_inv2.create_rectangle(0, 0, canvas_width, canvas_height,
-		fill="#5050ff", outline="Black", tags="background_box")
+		fill=g.fill_colour, outline="Black", tags="background_box")
 	#text
 	canvas_inv2.create_text(3, 3, text=line, anchor="nw",
 		width=canvas_width-6, tags="dialogtxt")
@@ -301,7 +301,7 @@ def refresh_inv():
 			(curr_item%inv_width)*g.tilesize + 2 * ((curr_item%inv_width)+1),
 			(curr_item/inv_width)*g.tilesize + 2 * ((curr_item/inv_width)+1),
 			((curr_item%inv_width)+1)*(g.tilesize + 2),
-			((curr_item/inv_width)+1)*(g.tilesize + 2), fill="#A0A0ff", tags="item")
+			((curr_item/inv_width)+1)*(g.tilesize + 2), fill=g.fill_sel_colour, tags="item")
 
 	#draw the item pictures.
 	for i in range(len(item.inv)):
@@ -558,7 +558,7 @@ def init_window_inv():
 	temp_canvas_height=(g.tilesize*inv_height)+ ((inv_height+1)*2) + 1
 	global canvas_inv
 	canvas_inv = Canvas(window_inv, width=temp_canvas_width,
-		height=temp_canvas_height, highlightthickness=0, bg="#202090")
+		height=temp_canvas_height, highlightthickness=0, bg=g.outline_colour)
 	canvas_inv.grid(column=1, row=2, rowspan=10)
 	#outside border
 	canvas_inv.create_rectangle(0,0, temp_canvas_width-1, temp_canvas_height-1)
@@ -568,7 +568,7 @@ def init_window_inv():
 			canvas_inv.create_rectangle(x*g.tilesize + 2 * (x+1),
 										y*g.tilesize + 2 * (y+1),
 										(x+1)*(g.tilesize + 2),
-										(y+1)*(g.tilesize + 2), fill="#5050ff")
+										(y+1)*(g.tilesize + 2), fill=g.fill_colour)
 
 	global listbox_equip
 	listbox_equip = Listbox(window_inv, height=10, takefocus=0, bg=bgcolour)
