@@ -1,5 +1,5 @@
 #file: map_editor.py
-#Copyright (C) 2004 Free Software Foundation
+#Copyright (C) 2005 Free Software Foundation
 #see GPL.txt for license.
 
 # This file runs a map editing program.
@@ -17,6 +17,10 @@ import tkMessageBox
 import load_map
 import re
 
+window = Toplevel()
+window.master.withdraw()
+window.title("Map Editor")
+
 import g
 import scripting
 
@@ -28,9 +32,6 @@ portal_y = 0
 portalsize = 15
 
 bgcolour='lightgrey'
-window = Toplevel()
-window.master.withdraw()
-window.title("Map Editor")
 
 cur_tile = ""
 cur_tile_num = 0
@@ -190,7 +191,7 @@ def refresh_map():
 				line.strip().split()[0].strip().lower() == "addpix":
 					canvas_map.create_image((x-portal_x)*g.tilesize,
 						(y-portal_y)*g.tilesize, anchor=NW,
-						image=g.tiles[line.strip().split()[1].strip()])
+						image=g.tiles[line.strip().split(None, 1)[1].strip()])
 				elif len(line.strip().split()) >= 8 and \
 				line.strip().split()[6].strip().lower() == "addpix":
 					canvas_map.create_image((x-portal_x)*g.tilesize,
@@ -478,9 +479,11 @@ def save_map(event=0):
 	map_file.write("\n:def\n")
 	for monster_name in cur_map.monster:
 		map_file.write("monster=" + monster_name + "\n")
+	if cur_map.battle_background_name != "":
+		map_file.write("battle_bg=" + cur_map.battle_background_name + "\n")
 
 	#use the upper-left tile as background.
-	map_file.write(":a\n" + "pix ")
+	map_file.write(":a\n")
 	for onload_line in cur_map.field[0][0].onload:
 		if onload_line.split()[0].strip().lower() == "pix":
 			map_file.write(onload_line + "\n")
@@ -534,6 +537,7 @@ def copy_map(output_map, input_map):
 			copy_tile(output_map.field[y][x], input_map.field[y][x])
 	for monster in input_map.monster:
 		output_map.monster.append(monster)
+	output_map.battle_background_name = input_map.battle_background_name
 
 #given input and output tiles, copies the important parts.
 def copy_tile(output_tile, input_tile):
