@@ -1,5 +1,5 @@
 #monster.py
-#Copyright (C) 2004 Free Software Foundation
+#Copyright (C) 2005 Free Software Foundation
 #see GPL.txt for license.
 
 #This file contains everything about the monsters.
@@ -24,6 +24,9 @@ class monster_class:
 		self.exp = int(exp)
 		self.gold = int(gold)
 		self.description = str(descript)
+		#An array of lines, describing the scripting run when the monster dies.
+		#If given, this replaces the exp/gold giving code.
+		self.on_death = []
 	def reset(self):  #resets the monster for a battle
 		self.hp = self.maxhp
 
@@ -122,6 +125,9 @@ def addmonster(filename):
 	temp_exp = 0
 	temp_gold = 0
 	temp_description = ""
+	temp_on_death = []
+
+	curr_mode = 0  #are we reading in a script (1) or variables (0)?
 
 	monster_loc = g.mod_directory + "/data/monsters/" + filename
 	monster_file = open(monster_loc, 'r')
@@ -138,6 +144,11 @@ def addmonster(filename):
 		while monster_line[-1:] == "\\": #really a single backslash, BTW.
 				monster_line = monster_line[:-1] + monster_file.readline()[:-1]
 
+		if curr_mode == 1:
+			temp_on_death.append(monster_line)
+			monster_line = monster_file.readline()
+			continue
+
 		monster_command = monster_line.split("=", 2)[0]
 		monster_command = monster_command.strip()
 		if (monster_command.lower() == "name"):
@@ -154,6 +165,8 @@ def addmonster(filename):
 			temp_gold = monster_line.split("=", 1)[1]
 		elif (monster_command.lower() == "description"):
 			temp_description = monster_line.split("=", 1)[1]
+		elif (monster_command.lower() == ":on_death"):
+			curr_mode = 1
 		else:
 			print "bad line of " + monster_line + " found in " + filename
 		#ready another line
@@ -164,3 +177,7 @@ def addmonster(filename):
 	#actually add the monster
 	monsters.append(monster_class(temp_name, temp_hp, temp_attack,
 		temp_defense, temp_exp, temp_gold, temp_description))
+
+	for line in temp_on_death:
+		monsters[len(monsters)-1].on_death.append(line)
+
