@@ -1,5 +1,5 @@
 #file: scripting.py
-#Copyright (C) 2004 Free Software Foundation
+#Copyright (C) 2005 Free Software Foundation
 #see GPL.txt for license.
 
 #This file controls the loading of datafiles.
@@ -58,6 +58,11 @@ class map:
 		self.field = [] #multidimentional array of tile class members.
 		self.monster = [] #monsters that can attack on this level.
 
+		#filename of the background image used in battles. Used in the map editor
+		self.battle_background_name = ""
+		#Filled in with a Tkinter image reference
+		self.battle_background = ""
+
 		self.maptext = [] #unused after load
 		self.tiles = {} #unused after load
 		self.per_tile_info = [] #unused after load
@@ -106,12 +111,19 @@ class map:
 			map_command = map_command.strip()
 			if map_command.lower() == "monster":
 				self.monster.append(map_line.split("=", 1)[1])
+			elif map_command.lower() == "battle_bg":
+				self.battle_background = \
+					g.backgrounds[map_line.split("=", 1)[1].strip()]
+				self.battle_background_name = \
+					map_line.split("=", 1)[1].strip()
 			else:
 				print "bad command of " + map_command + " received"
 
 			#ready another line
 			map_line = map_file.readline()
 
+		if self.battle_background == "":
+			self.battle_background = g.backgrounds["generic.png"]
 		#input tile data
 		current_tile = ""
 		mode=0
@@ -245,6 +257,8 @@ maps = []
 #read the data/maps directory and place in maps[]. This called at startup.
 def read_maps():
 	del maps[:]
+	g.load_backgrounds()
+
 
 	#put the names of the available maps in array_maps.
 	array_maps = listdir(g.mod_directory + "/data/maps")
